#!/usr/bin/env node
"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const commander_1 = require("commander");
const node_child_process_1 = require("node:child_process");
const debug_1 = __importDefault(require("debug"));
const version_1 = require("./version");
const secretsmanager_1 = require("./vaults/secretsmanager");
const debug = (0, debug_1.default)('env-secrets');
const program = new commander_1.Command();
// main program
program
    .name('env-secrets')
    .description('pull secrets from vaults and inject them into the running environment')
    .version(version_1.LIB_VERSION);
// aws secretsmanager
program
    .command('aws')
    .description('get secrets from AWS secrets manager')
    .addArgument(new commander_1.Argument('[program...]', 'program to run'))
    .requiredOption('-s, --secret <secret>', 'secret to get')
    .option('-p, --profile <profile>', 'profile to use')
    .option('-r, --region <region>', 'region to use')
    .action((program, options) => __awaiter(void 0, void 0, void 0, function* () {
    let env = yield (0, secretsmanager_1.secretsmanager)(options);
    env = Object.assign({}, process.env, env);
    debug(env);
    if (program && program.length > 0) {
        debug(`${program[0]} ${program.slice(1)}`);
        (0, node_child_process_1.spawn)(program[0], program.slice(1), {
            stdio: 'inherit',
            shell: true,
            env
        });
    }
}));
program.parse();
