"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.secretsmanager = void 0;
const aws_sdk_1 = __importDefault(require("aws-sdk"));
const debug_1 = __importDefault(require("debug"));
const debug = (0, debug_1.default)('env-secrets:secretsmanager');
const checkConnection = () => __awaiter(void 0, void 0, void 0, function* () {
    const sts = new aws_sdk_1.default.STS();
    const getCallerPromise = new Promise((resolve, reject) => {
        sts.getCallerIdentity({}, (err, data) => {
            if (err)
                reject(err);
            else {
                resolve(data);
            }
        });
    });
    let value;
    let err;
    yield getCallerPromise
        .then((v) => {
        value = v;
    })
        .catch((e) => {
        err = e;
    });
    if (err) {
        console.error(err);
        return false;
    }
    debug(value);
    return !!value;
});
const secretsmanager = (options) => __awaiter(void 0, void 0, void 0, function* () {
    const { secret, profile, region } = options;
    const { AWS_ACCESS_KEY_ID: awsAccessKeyId, AWS_SECRET_ACCESS_KEY: awsSecretAccessKey } = process.env;
    if (profile) {
        debug(`Using profile: ${profile}`);
        const credentials = new aws_sdk_1.default.SharedIniFileCredentials({
            profile
        });
        aws_sdk_1.default.config.credentials = credentials;
    }
    else if (awsAccessKeyId && awsSecretAccessKey) {
        debug('Using environment variables');
    }
    else {
        debug('Using profile: default');
    }
    if (region) {
        aws_sdk_1.default.config.update({ region });
    }
    if (!aws_sdk_1.default.config.region) {
        debug('no region set');
    }
    const connected = yield checkConnection();
    if (connected) {
        const sm = new aws_sdk_1.default.SecretsManager();
        try {
            const response = yield sm
                .getSecretValue({
                SecretId: secret
            })
                .promise();
            const secretvalue = response.SecretString;
            try {
                if (secretvalue) {
                    return JSON.parse(secretvalue);
                }
            }
            catch (err) {
                console.error(err);
            }
        }
        catch (err) {
            if (err && err.code === 'ResourceNotFoundException') {
                console.error(`${secret} not found`);
            }
            else if (err && err.code === 'ConfigError') {
                console.error(err.message);
            }
            else {
                console.error(err);
            }
        }
        return {};
    }
    else {
        console.error('Unable to connect to AWS');
    }
});
exports.secretsmanager = secretsmanager;
